@@ -198,10 +198,6 @@ def create_and_save_graph(
 
     utils.save_graph(dir_path, filename, dot_str)
 
-    graph_svg = utils.render_dot(dot_str, out_type="svg")
-
-    return graph_svg
-
 
 def create_graphs(
     m: Model,
@@ -211,15 +207,19 @@ def create_graphs(
     show_nr_indiv,
     final_var_in_percent=False,
     ids: Optional[Sequence[str]] = None,
+    graph_types=("ADE", "AME", "ATE", "IDE", "IME", "ITE"),
 ):
     """creates direct, total and mediation graph,
     for theoretical model and estimated model"""
 
     def make_graph(filename, x_weights_idmat_nodeff, y_weights_idmat_nodeff, **kwargs):
+        if filename[:3] not in graph_types:
+            return
+
         print(filename)
         xnodes = [str(var) for var in m.xvars]
         ynodes = [str(var) for var in m.yvars]
-        return create_and_save_graph(
+        create_and_save_graph(
             xnodes,
             ynodes,
             x_weights_idmat_nodeff,
@@ -229,6 +229,7 @@ def create_graphs(
             node_name,
             **kwargs,
         )
+        return filename
 
     print("\nAverage and estimated graphs")
     direct_graph = make_graph(
